@@ -8,7 +8,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
  * as published by the Free Software Foundation; version 2.1 of
- * the License.
+ * the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -27,7 +27,8 @@
  * @short_description: A keypad-like widget used to enter pincodes.
  *
  * #HildonCodeDialog displays a keypad that can be used to enter 
- * numerical pin codes or lock codes. 
+ * numerical pin codes or lock codes. It emits a 'input' signal each time 
+ * an input action is performed on the dialog.
  *
  */
 
@@ -97,8 +98,16 @@ hildon_code_dialog_key_press_event              (GtkWidget *widget,
                                                  GdkEventKey *event,
                                                  gpointer user_data);
 
+static void 
+hildon_code_dialog_real_input                   (HildonCodeDialog *dialog);
+
+static void
+hildon_code_dialog_input                        (HildonCodeDialog *dialog);
+
 static GtkDialogClass*                          parent_class = NULL;
 
+static guint                                    input_signal;
+
 /**
  * hildon_code_dialog_get_type:
  *
@@ -136,6 +145,18 @@ hildon_code_dialog_class_init                   (HildonCodeDialogClass *cd_class
 {
     parent_class = GTK_DIALOG_CLASS (g_type_class_peek_parent (cd_class));
     g_type_class_add_private (cd_class, sizeof (HildonCodeDialogPrivate));
+
+    cd_class->input = hildon_code_dialog_real_input;
+
+    /* FIXME Document this signal! */
+    input_signal = g_signal_new("input",
+                                HILDON_TYPE_CODE_DIALOG,
+                                G_SIGNAL_RUN_LAST,
+                                G_STRUCT_OFFSET (HildonCodeDialogClass, input),
+                                NULL, NULL,
+                                g_cclosure_marshal_VOID__VOID,
+                                G_TYPE_NONE,
+                                0);
 }
 
 static void 
@@ -169,6 +190,7 @@ hildon_code_dialog_init                         (HildonCodeDialog *dialog)
     gtk_window_set_title (GTK_WINDOW (dialog), DEVICELOCK_TITLE);
 
     gtk_window_set_type_hint (GTK_WINDOW (dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
+    gtk_dialog_set_has_separator ((GtkDialog *) dialog, FALSE);
 
     hints.min_width  = -1;
     hints.min_height = -1;
@@ -303,6 +325,7 @@ hildon_code_dialog_init                         (HildonCodeDialog *dialog)
     g_signal_connect (G_OBJECT (cancelButton), "key-press-event",
                 G_CALLBACK (hildon_code_dialog_key_press_event), dialog);
 
+    gtk_widget_show_all (GTK_WIDGET (GTK_DIALOG (dialog)->vbox));
 }
 
 static void 
@@ -376,6 +399,8 @@ hildon_code_dialog_insert_text                  (GtkEditable *editable,
         /* make the Ok button sensitive */
         gtk_widget_set_sensitive (priv->buttons[4][0], TRUE);
     }
+
+    hildon_code_dialog_input (dialog);
 }
 
 static gboolean 
@@ -505,3 +530,44 @@ hildon_code_dialog_set_help_text                (HildonCodeDialog *dialog,
 
     gtk_label_set_text (GTK_LABEL (priv->help_text), text);
 }
+
+static void 
+hildon_code_dialog_real_input                   (HildonCodeDialog *dialog)
+{
+}
+
+static void 
+hildon_code_dialog_input                        (HildonCodeDialog *dialog)
+{
+    /* Emit the signal */
+    g_signal_emit (dialog, input_signal, 0);
+}
+
+/**
+ * hildon_code_dialog_set_input_sensitive
+ * @dialog: The #HildonCodeDialog whose state is to be changed
+ * @sensitive: The new state 
+ *
+ * This function will block or enable the input on the code dialog by
+ * making the input button sensitive (or not).
+ **/
+void
+hildon_code_dialog_set_input_sensitive          (HildonCodeDialog *dialog, 
+                                                 gboolean sensitive)
+{
+    int i;
+    int k;
+
+    g_return_if_fail (HILDON_IS_CODE_DIALOG (dialog));
+
+    HildonCodeDialogPrivate *priv = HILDON_CODE_DIALOG_GET_PRIVATE (dialog);
+    g_assert (priv);
+
+    for (i = 0; i < 5; i++)
+        for (k = 0; k < 3; k++) 
+            if (i != 4 && (k != 0 || k != 2))
+                gtk_widget_set_sensitive (priv->buttons [i][k], sensitive);
+
+    gtk_widget_set_sensitive (priv->help_text, sensitive);
+    gtk_widget_set_sensitive (priv->entry, sensitive);
+}
