@@ -9,7 +9,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
  * as published by the Free Software Foundation; version 2.1 of
- * the License.
+ * the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,7 +25,7 @@
 
 /**
  * SECTION:hildon-color-chooser-dialog
- * @short_description: A dialog used to select a color from HSV colorspace
+ * @short_description: A dialog used to select a color from HSV colorspace.
  * @see_also: #HildonColorButton
  *
  * HildonColorChooserDialog enables the user to 
@@ -38,7 +38,6 @@
  *
  */
 
-
 #ifdef                                          HAVE_CONFIG_H
 #include                                        <config.h>
 #endif
@@ -296,7 +295,6 @@ hildon_color_chooser_dialog_class_init          (HildonColorChooserDialogClass *
                 GTK_TYPE_BORDER,
                 G_PARAM_READABLE));
 
-
     gtk_widget_class_install_style_property (widget_klass,
             g_param_spec_boxed ("default_color", "Default color",
                 "Default color for nonpainted custom colors",
@@ -518,6 +516,7 @@ hildon_color_chooser_dialog_style_set           (GtkWidget *widget,
 
     if (tmpcolor) {
         priv->style_info.default_color = *tmpcolor;
+	gdk_color_free (tmpcolor);
     } else {
         priv->style_info.default_color.red   = 0x0000;
         priv->style_info.default_color.green = 0x0000;
@@ -595,6 +594,7 @@ hildon_color_chooser_dialog_style_set           (GtkWidget *widget,
 
         if (tmpcolor) {
             priv->colors_defined[i] = *tmpcolor;
+	    gdk_color_free (tmpcolor);
         } else {
             if(i < 16) {
                 priv->colors_defined[i] = hardcoded_colors[i];
@@ -780,6 +780,17 @@ hildon_color_chooser_dialog_destroy             (GtkObject *object)
     GTK_OBJECT_CLASS (parent_class)->destroy (object);
 }
 
+/**
+ * hildon_color_chooser_dialog_set_color:
+ * @dialog: a #HildonColorChooserDialog
+ * @color: a color to set on the #HildonColorChooserDialog
+ *
+ * Sets the dialog to point at the given color. It'll first try to
+ * search the palette of the existing colors to match the passed color. 
+ * If the color is not found in the pallette, the color in the currently 
+ * selected box will be modified.
+ *
+ */
 void 
 hildon_color_chooser_dialog_set_color           (HildonColorChooserDialog *dialog, 
                                                  GdkColor *color)
@@ -954,16 +965,16 @@ hildon_color_chooser_dialog_color_changed       (HildonColorChooser *chooser,
     HildonColorChooserDialogPrivate *priv = HILDON_COLOR_CHOOSER_DIALOG_GET_PRIVATE (data);
     char key[128], color_str[13];
     int tmp;
-    GdkColor *color = g_new (GdkColor, 1);
+    GdkColor color;
 
     g_assert (priv);
 
-    hildon_color_chooser_get_color (chooser, color);
+    hildon_color_chooser_get_color (chooser, &color);
 
     tmp = (priv->style_info.num_buttons.left * priv->style_info.num_buttons.right);
 
     if (priv->selected >= tmp) {
-        priv->colors_custom[priv->selected - tmp] = *color;
+        priv->colors_custom[priv->selected - tmp] = color;
 
         gdk_gc_set_rgb_fg_color (priv->gc_array[priv->selected], &priv->colors_custom[priv->selected - tmp]);
         gtk_widget_queue_draw (priv->area_custom);
@@ -1110,7 +1121,9 @@ hildon_color_chooser_dialog_new                 (void)
 /**
  * hildon_color_chooser_dialog_get_color:
  * @dialog: a #HildonColorChooserDialog
- * @color: a color to fill with new value
+ * @color: a color structure to fill with the currently selected color
+ *
+ * Retrives the currently selected color in the color chooser dialog.
  *
  */
 void
