@@ -8,7 +8,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
  * as published by the Free Software Foundation; version 2.1 of
- * the License.
+ * the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,7 +25,7 @@
 /**
  * SECTION:hildon-time-editor
  * @short_description: A widget used to enter time or duration in hours, minutes,
- * and optional seconds
+ * and optional seconds.
  * @see_also: #HildonTimePicker
  * 
  * HildonTimeEditor is used to edit time or duration. Time mode is
@@ -61,6 +61,7 @@
 #include                                        <gtk/gtklabel.h>
 #include                                        <gtk/gtkframe.h>
 #include                                        <gdk/gdkkeysyms.h>
+#include                                        <gtk/gtkenums.h>
 #include                                        <string.h>
 #include                                        <time.h>
 #include                                        <stdlib.h>
@@ -69,7 +70,6 @@
 #include                                        "hildon-defines.h"
 #include                                        "hildon-time-picker.h"
 #include                                        "hildon-banner.h"
-#include                                        "hildon-input-mode-hint.h"
 #include                                        "hildon-private.h"
 #include                                        "hildon-marshalers.h"
 #include                                        "hildon-enum-types.h"
@@ -224,19 +224,22 @@ static void
 hildon_time_editor_size_allocate                (GtkWidget *widget,
                                                  GtkAllocation *allocation);
 
-static gboolean 
-hildon_time_editor_entry_keypress               (GtkWidget *widget,
-                                                 GdkEventKey *event,
-                                                 gpointer data);
+static gboolean
+hildon_time_editor_entry_keypress (GtkEntry *entry,
+                                   GdkEventKey* event,
+                                   gpointer user_data);
 
 static gboolean
 hildon_time_editor_check_locale                 (HildonTimeEditor *editor);
 
+#ifdef MAEMO_GTK 
 static void 
 hildon_time_editor_tap_and_hold_setup           (GtkWidget *widget,
                                                  GtkWidget *menu,
                                                  GtkCallback func,
                                                  GtkWidgetTapAndHoldFlags flags);
+#endif
+
 static void
 hildon_time_editor_validate                     (HildonTimeEditor *editor, 
                                                  gboolean allow_intermediate);
@@ -359,7 +362,9 @@ hildon_time_editor_class_init                   (HildonTimeEditorClass *editor_c
     object_class->set_property                  = hildon_time_editor_set_property;
     widget_class->size_request                  = hildon_time_editor_size_request;
     widget_class->size_allocate                 = hildon_time_editor_size_allocate;
+#ifdef MAEMO_GTK 
     widget_class->tap_and_hold_setup            = hildon_time_editor_tap_and_hold_setup;
+#endif
     widget_class->focus                         = hildon_private_composite_focus;
 
     container_class->forall                     = hildon_time_editor_forall;
@@ -455,6 +460,7 @@ hildon_time_editor_class_init                   (HildonTimeEditorClass *editor_c
                 G_PARAM_READABLE | G_PARAM_WRITABLE) );
 }
 
+#ifdef MAEMO_GTK 
 static void 
 hildon_time_editor_tap_and_hold_setup           (GtkWidget *widget,
                                                  GtkWidget *menu,
@@ -475,6 +481,7 @@ hildon_time_editor_tap_and_hold_setup           (GtkWidget *widget,
     gtk_widget_tap_and_hold_setup (priv->iconbutton, menu, func,
             GTK_TAP_AND_HOLD_NONE);
 }
+#endif
 
 static void 
 hildon_time_editor_entry_changed                (GtkWidget *widget, 
@@ -532,8 +539,10 @@ hildon_time_editor_init                         (HildonTimeEditor *editor)
         /* No frames for entries, so that they all appear to be inside one long entry */
         gtk_entry_set_has_frame (GTK_ENTRY (priv->entries[i]), FALSE);
 
+#ifdef MAEMO_GTK 
         /* Set the entries to accept only numeric characters */
-        g_object_set (priv->entries[i], "input-mode", HILDON_INPUT_MODE_HINT_NUMERIC, NULL);
+        g_object_set (priv->entries[i], "hildon-input-mode", HILDON_GTK_INPUT_MODE_NUMERIC, NULL);
+#endif
 
         /* The entry fields all take exactly two characters */
         gtk_entry_set_max_length (GTK_ENTRY (priv->entries[i]), 2);
@@ -698,8 +707,11 @@ hildon_time_editor_finalize                     (GObject *obj_self)
     HildonTimeEditorPrivate *priv = HILDON_TIME_EDITOR_GET_PRIVATE (obj_self);
     g_assert (priv);
 
-    g_free (priv->am_symbol);
-    g_free (priv->pm_symbol);
+    if (priv->am_symbol) 
+            g_free (priv->am_symbol);
+
+    if (priv->pm_symbol)
+            g_free (priv->pm_symbol);
 
     if (priv->highlight_idle)
         g_source_remove (priv->highlight_idle);
@@ -793,7 +805,7 @@ hildon_time_editor_set_ticks                    (HildonTimeEditor *editor,
     guint i, h, m, s;
     gchar str[3];
 
-    g_assert (HILDON_IS_TIME_EDITOR (editor));
+    g_return_if_fail (HILDON_IS_TIME_EDITOR (editor));
 
     priv = HILDON_TIME_EDITOR_GET_PRIVATE (editor);
     g_assert (priv);
@@ -1764,76 +1776,22 @@ hildon_time_editor_size_allocate                (GtkWidget *widget,
     gtk_widget_size_allocate (priv->sec_label, &alloc);
 }
 
-static gboolean 
-hildon_time_editor_entry_keypress               (GtkWidget *widget,
-                                                 GdkEventKey *event,
-                                                 gpointer data)
+static gboolean
+hildon_time_editor_entry_keypress (GtkEntry *entry,
+                                   GdkEventKey *event,
+                                   gpointer data)
 {
-    HildonTimeEditor *editor;
-    HildonTimeEditorPrivate *priv;
-    gint cursor_pos;
-    gboolean r;
-
-    g_assert (GTK_IS_ENTRY (widget));
-    g_assert (event != NULL);
-    g_assert (HILDON_IS_TIME_EDITOR (data));
-
-    editor = HILDON_TIME_EDITOR (data);
-    priv = HILDON_TIME_EDITOR_GET_PRIVATE (editor);
-    g_assert (priv); 
-    cursor_pos = gtk_editable_get_position (GTK_EDITABLE (widget));
-
-    /* Show error message in case the key pressed is not allowed 
-       (only digits and control characters are allowed )*/
-    if (!g_unichar_isdigit (event->keyval) && ! (event->keyval & 0xF000)) {
-        g_signal_emit (editor, time_editor_signals[TIME_ERROR], 0, HILDON_DATE_TIME_ERROR_INVALID_CHAR, &r);
-        hildon_banner_show_information (widget, NULL, c_("ckct_ib_illegal_character"));
-        return TRUE;
+  switch (event->keyval)
+    {
+    case GDK_Return:
+    case GDK_ISO_Enter:
+      hildon_time_editor_icon_clicked (entry, data);
+      return TRUE;
+    default:
+      return FALSE;
     }
 
-    switch (event->keyval)
-    {
-        case GDK_Return:
-            /* Return key popups up time picker dialog. Visually it looks as if
-               the time picker icon was clicked. Before opening the time picker
-               the fields are first validated and fixed. */
-
-            /* hildon_time_editor_validate (editor, FALSE);
-               hildon_gtk_button_set_depressed (GTK_BUTTON (priv->iconbutton), TRUE);
-               hildon_time_editor_icon_clicked (widget, data);
-               hildon_gtk_button_set_depressed (GTK_BUTTON (priv->iconbutton), FALSE); 
-
-               FIXME The above code used to be here before the consolidation that removed the 
-               _set_depressed crap. However, I think this code had NO EFFECT anyways, since
-               there is no expose event after the _set functions. So I'm just cutting it out. 
-               Another story would be to actually fix it... */
-                
-            hildon_time_editor_icon_clicked (widget, data);
-            return TRUE;
-
-        case GDK_Left:
-            /* left arrow pressed in the entry. If we are on first position, try to
-               move to the previous field. */
-            if (cursor_pos == 0) {
-                (void) gtk_widget_child_focus (GTK_WIDGET (editor), GTK_DIR_LEFT);
-                return TRUE;
-            }
-            break;
-
-        case GDK_Right:
-            /* right arrow pressed in the entry. If we are on last position, try to
-               move to the next field. */
-            if (cursor_pos >= g_utf8_strlen (gtk_entry_get_text (GTK_ENTRY (widget)), -1)) {
-                (void) gtk_widget_child_focus (GTK_WIDGET (editor), GTK_DIR_RIGHT);    
-                return TRUE;
-            }
-            break;
-
-        default:
-            break;
-    };
-
-    return FALSE;
+  g_assert_not_reached ();
 }
 
 static void
